@@ -51,5 +51,5 @@ class CLIVersionPlugin(CLIPlugin):
             ver = versions[key]
             verlines = ver.splitlines()
             print(f"{key.ljust(keylen)}: {verlines.pop(0)}")
-            for verline in verlines:
+            for verline in verlines:  # pragma: no cover
                 print(f"{' ' * keylen}  {verline}")
